@@ -33,10 +33,6 @@ namespace Ui {
 class EventOrTodoDesktop;
 }
 
-namespace KCalCore {
-class ICalTimeZones;
-}
-
 namespace IncidenceEditorNG {
 class IncidenceDateTime : public IncidenceEditor
 {
@@ -45,11 +41,11 @@ public:
     using IncidenceEditorNG::IncidenceEditor::save; // So we don't trigger -Woverloaded-virtual
     using IncidenceEditorNG::IncidenceEditor::load; // So we don't trigger -Woverloaded-virtual
     explicit IncidenceDateTime(Ui::EventOrTodoDesktop *ui);
-    ~IncidenceDateTime();
+    ~IncidenceDateTime() override;
 
     void load(const KCalCore::Incidence::Ptr &incidence) override;
     void save(const KCalCore::Incidence::Ptr &incidence) override;
-    bool isDirty() const override;
+    Q_REQUIRED_RESULT bool isDirty() const override;
 
     /**
      * Sets the active date for the editing session. This defaults to the current
@@ -58,22 +54,22 @@ public:
      */
     void setActiveDate(const QDate &activeDate);
 
-    QDate startDate() const; /// Returns the current start date.
-    QTime startTime() const; /// Returns the current start time.
-    QDate endDate() const; /// Returns the current end date.
-    QTime endTime() const; /// Returns the current endtime.
+    Q_REQUIRED_RESULT QDate startDate() const; /// Returns the current start date.
+    Q_REQUIRED_RESULT QTime startTime() const; /// Returns the current start time.
+    Q_REQUIRED_RESULT QDate endDate() const; /// Returns the current end date.
+    Q_REQUIRED_RESULT QTime endTime() const; /// Returns the current endtime.
 
     /// Created from the values in the widgets
-    KDateTime currentStartDateTime() const;
-    KDateTime currentEndDateTime() const;
+    Q_REQUIRED_RESULT QDateTime currentStartDateTime() const;
+    Q_REQUIRED_RESULT QDateTime currentEndDateTime() const;
 
     void setStartTime(const QTime &newTime);
     void setStartDate(const QDate &newDate);
 
-    bool startDateTimeEnabled() const;
-    bool endDateTimeEnabled() const;
+    Q_REQUIRED_RESULT bool startDateTimeEnabled() const;
+    Q_REQUIRED_RESULT bool endDateTimeEnabled() const;
 
-    bool isValid() const override;
+    Q_REQUIRED_RESULT bool isValid() const override;
     void printDebugInfo() const override;
 
 Q_SIGNALS:
@@ -104,9 +100,9 @@ private Q_SLOTS: /// Todo specific
     void enableStartEdit(bool enable);
     void enableEndEdit(bool enable);
     void enableTimeEdits();
-    bool isDirty(const KCalCore::Todo::Ptr &todo) const;
 
-private Q_SLOTS: /// Event specific
+private:
+    bool isDirty(const KCalCore::Todo::Ptr &todo) const;
     bool isDirty(const KCalCore::Event::Ptr &event) const;
     bool isDirty(const KCalCore::Journal::Ptr &journal) const;
 
@@ -114,23 +110,19 @@ protected:
     bool eventFilter(QObject *obj, QEvent *event) override;
 
 private:
-    void load(const KCalCore::Event::Ptr &event, bool isTemplate = false,
-              bool templateOverridesTimes = false);
-    void load(const KCalCore::Todo::Ptr &todo, bool isTemplate = false,
-              bool templateOverridesTimes = false);
-    void load(const KCalCore::Journal::Ptr &journal, bool isTemplate = false,
-              bool templateOverridesTimes = false);
+    void load(const KCalCore::Event::Ptr &event, bool isTemplate = false, bool templateOverridesTimes = false);
+    void load(const KCalCore::Todo::Ptr &todo, bool isTemplate = false, bool templateOverridesTimes = false);
+    void load(const KCalCore::Journal::Ptr &journal, bool isTemplate = false, bool templateOverridesTimes = false);
     void save(const KCalCore::Event::Ptr &event);
     void save(const KCalCore::Todo::Ptr &todo);
     void save(const KCalCore::Journal::Ptr &journal);
-    void setDateTimes(const KDateTime &start, const KDateTime &end);
-    void setTimes(const KDateTime &start, const KDateTime &end);
+    void setDateTimes(const QDateTime &start, const QDateTime &end);
+    void setTimes(const QDateTime &start, const QDateTime &end);
     void setTimeZoneLabelEnabled(bool enable);
-    bool timeZonesAreLocal(const KDateTime &start, const KDateTime &end);
+    bool timeZonesAreLocal(const QDateTime &start, const QDateTime &end);
 
 private:
-    QVector<QByteArray> mTimeZones;
-    Ui::EventOrTodoDesktop *mUi;
+    Ui::EventOrTodoDesktop *mUi = nullptr;
 
     QDate mActiveDate;
     /**
@@ -138,14 +130,14 @@ private:
      * in account recurrence if needed. The values are calculated once on load().
      * and don't change afterwards.
      */
-    KDateTime mInitialStartDT;
-    KDateTime mInitialEndDT;
+    QDateTime mInitialStartDT;
+    QDateTime mInitialEndDT;
 
     /**
      * We need to store the current start date/time to be able to update the end
      * time appropriate when the start time changes.
      */
-    KDateTime mCurrentStartDateTime;
+    QDateTime mCurrentStartDateTime;
 
     /// Remembers state when switching between takes whole day and timed event/to-do.
     bool mTimezoneCombosWereVisibile;
